@@ -7,7 +7,7 @@
 #include "../src/decorationsettings.h"
 
 MockSettings::MockSettings(KDecoration3::DecorationSettings *parent)
-    : DecorationSettingsPrivate(parent)
+    : DecorationSettingsPrivateV2(parent)
 {
 }
 
@@ -41,6 +41,11 @@ bool MockSettings::isOnAllDesktopsAvailable() const
     return m_onAllDesktopsAvailable;
 }
 
+bool MockSettings::isAlwaysShowExcludeFromCapture() const
+{
+    return m_alwaysShowExcludeFromCapture;
+}
+
 void MockSettings::setOnAllDesktopsAvailabe(bool set)
 {
     if (m_onAllDesktopsAvailable == set) {
@@ -58,3 +63,12 @@ void MockSettings::setCloseOnDoubleClickOnMenu(bool set)
     m_closeDoubleClickOnMenu = set;
     Q_EMIT decorationSettings()->closeOnDoubleClickOnMenuChanged(m_closeDoubleClickOnMenu);
 }
+
+void MockSettings::setAlwaysShowExcludeFromCapture(bool set)
+{
+    if (m_alwaysShowExcludeFromCapture == set) {
+        return;
+    }
+    m_alwaysShowExcludeFromCapture = set;
+    Q_EMIT decorationSettings()->alwaysShowExcludeFromCaptureChanged(m_alwaysShowExcludeFromCapture);
+}
